﻿using System;
using System.Linq;
using System.Windows;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using Microsoft.Phone.Notification;
using System.Collections.ObjectModel;
using System.Collections.Generic;

namespace WPSample1
{
    public partial class MainPage : PhoneApplicationPage
    {
        //생성자
        public MainPage()
        {
            //푸쉬 채널생성
            HttpNotificationChannel pushChannel;
            //푸쉬 채널이름 설정
            string channelName = "TileSampleChannel";

            InitializeComponent();

            //채널이름 찾아보기
            pushChannel = HttpNotificationChannel.Find(channelName);
            if (pushChannel == null)
            {
                //생성된 채널이 없으면 생성
                pushChannel = new HttpNotificationChannel(channelName);
                //채널정보 업데이트시 이벤트 연결
                pushChannel.ChannelUriUpdated += new EventHandler<NotificationChannelUriEventArgs>(pushChannel_ChannelUriUpdated);
                //채널 오류 발생 이벤트 연결
                pushChannel.ErrorOccurred += new EventHandler<NotificationChannelErrorEventArgs>(pushChannel_ErrorOccurred);
                //채널 열기
                pushChannel.Open();
            }
            else
            {   
                //채널 업데이트 이벤트 연결
                pushChannel.ChannelUriUpdated +=new EventHandler<NotificationChannelUriEventArgs>(pushChannel_ChannelUriUpdated);
                //채널 오류 발생 이벤트 연결
                pushChannel.ErrorOccurred += new EventHandler<NotificationChannelErrorEventArgs>(pushChannel_ErrorOccurred);
                //채널 Uri정보 조회
                System.Diagnostics.Debug.WriteLine("[ChannelUri] " + pushChannel.ChannelUri.ToString());
            }

            this.Loaded += new RoutedEventHandler(MainPage_Loaded);
        }

        void MainPage_Loaded(object sender, RoutedEventArgs e)
        {
            MessageBox.Show("MainPage_Loaded");
        }

        void pushChannel_ErrorOccurred(object sender, NotificationChannelErrorEventArgs e)
        {
            //발생된 에러 메시지 조회
            Dispatcher.BeginInvoke(() =>
            {
                MessageBox.Show(String.Format("푸쉬 노티피케이션 {0} 에러 발생.  {1} ({2}) {3}",
                                    e.ErrorType, e.Message, e.ErrorCode, e.ErrorAdditionalData)
                                    );
            });
        }

        void pushChannel_ChannelUriUpdated(object sender, NotificationChannelUriEventArgs e)
        {
            Dispatcher.BeginInvoke(() => 
            {
                //sender를 푸시체널로 형변환하고
                HttpNotificationChannel pushChannel = sender as HttpNotificationChannel;
                //푸시체널을 어플리케이션타일과 바인딩
                pushChannel.BindToShellTile();

                //변경된 채널 Uri정보 디버그 창에 출력
                System.Diagnostics.Debug.WriteLine("[ChannelUri] " + e.ChannelUri.ToString());
            });
        }

        //하단 툴박스 클릭 이벤트 처리
        private void ApplicationBarIconButton_Click(object sender, System.EventArgs e)
        {
            ApplicationBarIconButton btn = sender as ApplicationBarIconButton;
            if (btn != null)
            {
                //ApplicationTile 가져오기
                var shellTile = ShellTile.ActiveTiles.FirstOrDefault(); 

                //SecondaryTile 가져오기
                //var shellTile = ShellTile.ActiveTiles
                //    .FirstOrDefault(p => p.NavigationUri.ToString().Contains("MainPage.xaml"));

                //버튼 텍스트를 가지구 어떤 버튼인지 확인
                switch (btn.Text)
                { 
                    case "Pin":
                        //SecondaryTile 새로 만들때 사용했던 부분
                        if (shellTile == null)
                        {
                            var tileData = new StandardTileData
                            {
                                Title = "Sample1",
                                Count = 1,
                                BackgroundImage = new Uri("/icons/appbar.sleep.png", UriKind.Relative),
                                BackTitle = "Back Sample1",
                                BackContent = "Back Content",
                                BackBackgroundImage = new Uri("/icons/appbar.sleep.dark.png", UriKind.Relative)
                            };
                            ShellTile.Create(new Uri("/MainPage.xaml", UriKind.Relative), tileData);

                            MessageBox.Show("Pin 작업을 완료했습니다.");
                        }
                        else
                        {
                            //ApplicationTile 업데이트 데이터 생성
                            var tileUpdate = new StandardTileData
                            {
                                Title = "AppTile",
                                Count = 1,
                                BackgroundImage = new Uri("/icons/appbar.sleep.png", UriKind.Relative),
                                BackTitle = "Back AppTile",
                                BackContent = "Back Content",
                                BackBackgroundImage = new Uri("/icons/appbar.sleep.dark.png", UriKind.Relative)
                            };
                            shellTile.Update(tileUpdate);

                            MessageBox.Show("ApplicationTile의 내용을 업데이트 했습니다~");
                        }
                        break;
                    case "Unpin":
                        //지금은 ApplicationTile을 가지고 놀고 있기 때문에 삭제 못함
                        //Unpin버튼이라면 타일이 존재하는 경우에 타일 제거
                        //if (shellTile != null)
                        //{
                        //    shellTile.Delete();
                        //    MessageBox.Show("UnPin 작업을 완료했습니다.");
                        //}
                        break;
                }
            }
        }
    }
}